@@ -20,10 +20,13 @@ has 'exp_month'       => (is => 'ro', isa => 'Maybe[Int]', required => 1);
 has 'exp_year'        => (is => 'ro', isa => 'Maybe[Int]', required => 1);
 
 # Output fields
-has 'country'         => (is => 'ro', isa => 'Maybe[Str]');
-has 'cvc_check'       => (is => 'ro', isa => 'Maybe[Str]');
-has 'last4'           => (is => 'ro', isa => 'Maybe[Str]');
-has 'type'            => (is => 'ro', isa => 'Maybe[Str]');
+has 'address_line_1_check' => (is => 'ro', isa => 'Maybe[Str]');
+has 'address_zip_check'    => (is => 'ro', isa => 'Maybe[Str]');
+has 'country'              => (is => 'ro', isa => 'Maybe[Str]');
+has 'cvc_check'            => (is => 'ro', isa => 'Maybe[Str]');
+has 'fingerprint'          => (is => 'ro', isa => 'Maybe[Str]');
+has 'last4'                => (is => 'ro', isa => 'Maybe[Str]');
+has 'type'                 => (is => 'ro', isa => 'Maybe[Str]');
 
 method form_fields {
     return (
@@ -34,24 +37,12 @@ method form_fields {
     );
 }
 
-=head1 NAME
-
-Net::Stripe::Card
-
-=head1 SEE ALSO
-
-L<https://stripe.com>, L<https://stripe.com/docs/api>
-
-=head1 AUTHORS
-
-Luke Closs
-
-=head1 LICENSE
-
-Net-Stripe is Copyright 2011 Prime Radiant, Inc.
-Net-Stripe is distributed under the same terms as Perl itself.
-
-=cut
 
 __PACKAGE__->meta->make_immutable;
 1;
+
+__END__
+
+=pod
+
+=cut
