@@ -10,34 +10,24 @@ has 'amount'            => (is => 'rw', isa => 'Maybe[Int]', required => 1);
 has 'currency'          => (is => 'rw', isa => 'Maybe[Str]', required => 1, clearer => 'clear_currency');
 has 'description'       => (is => 'rw', isa => 'Maybe[Str]');
 has 'date'              => (is => 'ro', isa => 'Maybe[Int]');
+has 'invoice'           => (is => 'ro', isa => 'Maybe[Str]');
+
 
 method form_fields {
     return (
         map { $_ => $self->$_ }
             grep { defined $self->$_ }
-                qw/amount currency description/,
+                qw/amount currency description invoice/,
                 ($self->id ? () : qw/customer/)
     );
 }
 
-=head1 NAME
-
-Net::Stripe::Invoiceitem
-
-=head1 SEE ALSO
-
-L<https://stripe.com>, L<https://stripe.com/docs/api>
-
-=head1 AUTHORS
-
-Luke Closs
-
-=head1 LICENSE
-
-Net-Stripe is Copyright 2011 Prime Radiant, Inc.
-Net-Stripe is distributed under the same terms as Perl itself.
-
-=cut
 
 __PACKAGE__->meta->make_immutable;
 1;
+
+__END__
+
+=pod
+
+=cut
