@@ -11,8 +11,8 @@ has 'currency'    => (is => 'ro', isa => 'Maybe[Str]');
 # Args returned by the API
 has 'id'          => (is => 'ro', isa => 'Maybe[Str]');
 has 'created'     => (is => 'ro', isa => 'Maybe[Int]');
-has 'used'        => (is => 'ro', isa => 'Maybe[Bool]');
-has 'livemode'    => (is => 'ro', isa => 'Maybe[Bool]');
+has 'used'        => (is => 'ro', isa => 'Maybe[Bool|Object]');
+has 'livemode'    => (is => 'ro', isa => 'Maybe[Bool|Object]');
 
 method form_fields {
     return (
@@ -23,25 +23,13 @@ method form_fields {
     );
 }
 
-=head1 NAME
-
-Net::Stripe::Token
-
-=head1 SEE ALSO
-
-L<https://stripe.com>, L<https://stripe.com/docs/api>
-
-=head1 AUTHORS
-
-Luke Closs
-
-=head1 LICENSE
-
-Net-Stripe is Copyright 2011 Prime Radiant, Inc.
-Net-Stripe is distributed under the same terms as Perl itself.
-
-=cut
 
 
 __PACKAGE__->meta->make_immutable;
 1;
+
+__END__
+
+=pod
+
+=cut
